AppUsage class

Constructors

AppUsage({String? appName, String? packageName, DateTime? lastTimeUsed, DateTime? firstTime, DateTime? lastTime, Duration? usageTime, Uint8List? iconInBytes, AppCategory category = AppCategory.undefined})
AppUsage.fromJson(Map<String, dynamic> json)
factory

Properties

appName → String?
final
category → AppCategory
final
firstTime → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
iconInBytes → Uint8List?
final
lastTime → DateTime?
final
lastTimeUsed → DateTime?
final
packageName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usageTime → Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited