InstalledApp class

Constructors

InstalledApp({String? appName, String? packageName, bool enabled = false, AppCategory category = AppCategory.undefined, String? versionName, int? versionCode, Uint8List? iconInBytes})
InstalledApp.fromJson(Map<String, dynamic> json)
factory

Properties

appName → String?
final
category → AppCategory
final
enabled → bool
final
hashCode → int
The hash code for this object.
no setterinherited
iconInBytes → Uint8List?
final
packageName → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionCode → int?
final
versionName → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited